# academic-contacts

Organize your academic contacts

![logo](https://raw.githubusercontent.com/trucomanx/AcademicContactsGui/main/screenshot.png)

## 1. Installing

To install the package from [PyPI](https://pypi.org/project/academic-contacts/), follow the instructions below:


```bash
pip install --upgrade academic-contacts
```

Execute `which academic-contacts` to see where it was installed, probably in `/home/USERNAME/.local/bin/academic-contacts`.

### Using

To start, use the command below:

```bash
academic-contacts
```
## 2. More information

If you want more information go to [doc](https://github.com/trucomanx/AcademicContactsGui/blob/main/doc) directory.

## 3. Buy me a coffee

If you find this tool useful and would like to support its development, you can buy me a coffee!  
Your donations help keep the project running and improve future updates.  

[☕ Buy me a coffee](https://ko-fi.com/trucomanx) 

## 4. License

This project is licensed under the GPL license. See the `LICENSE` file for more details.
